@@ -1,6 +1,7 @@
 """Configures and builds c/c++ source, given target configurations."""
 
 import os
+import multiprocessing
 
 #sudo easy_install termcolor
 import termcolor
@@ -184,7 +185,7 @@ class Builder:
     def __add_multiple_job_support():
         """Configure scons to start as many jobs as cores"""
 
-        num_cpu = int(os.environ.get('NUM_CPU', 2))
+        num_cpu = int(multiprocessing.cpu_count())
         SCons.Script.SetOption('num_jobs', num_cpu)
 
     @staticmethod
